@@ -202,7 +202,6 @@ class ImageEditor(wx.Panel):
                                  imageId=index)
         (costumes[index], costumes[index + 1]) = (costumes[index + 1],
                                                   costumes[index])
-        print costumes
 
     def OnItemFocused(self, event):
         self.toolbar.EnableTool(wx.ID_DELETE, len(self.sprite.costumes) > 1)
@@ -226,7 +225,7 @@ class ImageEditor(wx.Panel):
 
     def OnEdit(self, event):
         selection = self.listBook.GetSelection()
-        if config['IMAGE_EDITOR_PATH']:
+        if 'IMAGE_EDITOR_PATH' in config:
             path = os.path.join(tempfile.gettempdir(),
                                 '%s.png' % id(self.sprite.costumes[selection]))
             self.sprite.costumes[selection].save_to(path)
@@ -234,7 +233,7 @@ class ImageEditor(wx.Panel):
         else:
             error("Please configure editor!",
                   "You must configure your favorite image editor "
-                  "befor using this feature!")
+                  "before using this feature!")
 
     def OnRefresh(self, event):
         selection = self.listBook.GetSelection()
@@ -371,7 +370,7 @@ class LeftPanel(wx.Panel):
 
         self.pages = []
 
-        self.noteBook.SetMinSize((300, 450))
+        #self.noteBook.SetMinSize((300, 450))
         debug("Done.", -1)
         self.sizer.Add(self.noteBook, 1, wx.EXPAND)
         self.SetSizerAndFit(self.sizer)
@@ -384,7 +383,6 @@ class LeftPanel(wx.Panel):
             self.imageList = wx.ImageList(16, 16)
             self.noteBook.AssignImageList(self.imageList)
 
-
     def _NewPage(self, Window, title, bitmap, token):
         if self.welcomeOpen:
             self.noteBook.DeletePage(0)
